@@ -4,7 +4,7 @@
 
 package Device::USB::TEMPer1F;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use 5.008008;
 use strict;
@@ -67,6 +67,10 @@ sub new{
 # fetch temperature in °C
 sub fetch{
     my $self = shift;
+    if(! ref $self ){
+        $self = __PACKAGE__->new or die $@;
+    }
+    
     $self->_control();
     $self->{device}->interrupt_read($self->{cfg}{epi},$self->{buffer},8,$self->{cfg}{tim});
 
@@ -92,8 +96,8 @@ sub _control{
 }
 
 1;#########################################################################
-#  my $temper = Device::USB::TEMPer1F->new or die $@;
-#  print $temper->fetch;
+# my $temper = Device::USB::TEMPer1F->new or die $@;
+# print $temper->fetch;
 __END__
 
 =head1 NAME
@@ -104,9 +108,13 @@ Device::USB::TEMPer1F - Perl extension for USB PCSensor TEMPer1F
 
   use Device::USB::TEMPer1F;
 
+  Either
   my $temper = Device::USB::TEMPer1F->new or die $@;
-  print $temper->fetch; 
-    # 23.50
+  print $temper->fetch; # 23.50
+
+  Or
+  print Device::USB::TEMPer1F->fetch;
+  
 
 =head1 DESCRIPTION
 
@@ -133,6 +141,7 @@ Device::USB::TEMPer1F - Perl extension for USB PCSensor TEMPer1F
   Device::USB
   ppm install http://rolfrost.de/Device-USB.ppd
   ppm install http://rolfrost.de/Device-USB-PX1674.ppd
+  ppm install http://rolfrost.de/Device-USB-TEMPer1F.ppd
 
 =head1 AUTHOR
 
@@ -140,7 +149,7 @@ Rolf Rost, E<lt>pilgrim@rolfrost.deE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017 by Eolf Rost
+Copyright (C) 2017 by Rolf Rost
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.16.3 or,
